@@ -21,13 +21,94 @@ def add_cygdir(*args):
 
 def get_cygwin_dir():
 
-    cygwin_possibilities = cygwin_dirs + ['C:\\cygwin64']
+    cygwin_possibilities = cygwin_dirs + [os.path.join(lifelib_dir, 'cygwin', 'cygwin64'), 'C:\\cygwin64']
 
     for c in cygwin_possibilities:
-        if os.path.exists(c):
+        if os.path.exists(c) and os.path.exists(os.path.join(c, 'bin')):
             return c
 
-    raise ValueError("Cygwin directory unknown; please call lifelib.add_cygdir('D:\\\\path\\\\to\\\\cygwin64')")
+    raise ValueError("Cygwin directory unknown; please call lifelib.add_cygdir(r'D:\\path\\to\\cygwin64') or lifelib.install_cygwin()")
+
+
+def install_cygwin(root_directory=None, packages=['python2', 'python2-numpy', 'python3', 'python3-numpy', 'gcc-g++', 'make', 'git']):
+    '''
+    For lifelib to run correctly on Windows, there needs to be a 64-bit Cygwin
+    installation with g++, Python, and numpy. The user is free to download and
+    configure Cygwin herself; this is provided as a speedy alternative which
+    includes the prerequisites by default.
+
+    This will eventually result in a directory tree resembling the following:
+
+    lifelib--+--cygwin--+--cygwin-x86_64.exe
+             |          |
+             |          +--packages
+             |          |
+             |          +--cygwin64--+--bin-----bash.exe
+             |                       |
+             +--autocompile.py       +--etc
+             |                       |
+             +--cygbash.sh           +--usr
+             |                       |
+           [...]                   [...]
+
+    This has a certain elegance that uninstalling lifelib will remove the
+    internal Cygwin installation.
+    '''
+
+    try:
+        from urllib import urlretrieve
+    except ImportError:
+        from urllib.request import urlretrieve
+
+    package_directory = os.path.join(lifelib_dir, 'cygwin', 'packages')
+    cygwin_setup = os.path.join(lifelib_dir, 'cygwin', 'cygwin-x86_64.exe')
+
+    if root_directory is None:
+        root_directory = os.path.join(lifelib_dir, 'cygwin', 'cygwin64')
+
+    print("Preparing to install cygwin64 into %s..." % root_directory)
+
+    if not os.path.exists(package_directory):
+        os.makedirs(package_directory)
+
+    # Remove the setup-x86_64 executable if it already exists.
+    if os.path.exists(cygwin_setup):
+        os.remove(cygwin_setup)
+
+    # By downloading through HTTPS, the setup-x86_64 executable is secure
+    # against man-in-the-middle attacks. Beyond that, individual packages
+    # are secured by means of digital signatures and SHA-512 hashes; the
+    # public-key used to verify those is embedded in setup-x86_64.
+    print("Downloading Cygwin setup over HTTPS...")
+    urlretrieve("https://cygwin.com/setup-x86_64.exe", cygwin_setup)
+
+    args=[cygwin_setup, '-q', '--no-admin', '-n', '-N', '-d',
+            '-R', root_directory, '-l', package_directory,
+            '-s', 'http://mirrors.kernel.org/sourceware/cygwin',
+            '-P', ','.join(packages)]
+
+    # We are running in Linux, Mac OS X, or already inside Cygwin. In these
+    # cases, it does not make sense to install Cygwin.
+    if (os.name != 'nt'):
+        print("Skipping Cygwin installation since os.name != 'nt'.")
+        return
+
+    # Install Cygwin into a subdirectory of lifelib, complete with all of
+    # the dependencies used by lifelib.
+    print("Installing Cygwin...")
+    subprocess.check_call(args)
+    verify_installation()
+
+    print("Installation complete.")
+
+
+def verify_installation():
+
+    print("Verifying installation...")
+    subprocess.check_call(get_local_bash() + ['echo', 'SUCCESS'])
+
+    print("Verifying numpy is installed...")
+    subprocess.check_call(get_local_bash() + ['python', '-c', 'import numpy as np; print(np.__version__)'])
 
 
 def get_local_bash():
