@@ -36,10 +36,10 @@ class TestGoL(unittest.TestCase):
 
         try:
             lidka = self.lt.pattern("x = 9, y = 15, rule = B3/S23\nbo$obo$bo8$8bo$6bobo$5b2obo2$4b3o!")[30000]
-            lidka.save('lifelib/tempdir/lidka.rle')
-            lidka.save('lifelib/tempdir/lidka.rle.gz')
-            lidka.save('lifelib/tempdir/lidka.mc')
-            lidka.save('lifelib/tempdir/lidka.mc.gz')
+            lidka.save('lifelib/tempdir/lidka.rle', tempfile='lifelib/tempdir/tempfile')
+            lidka.save('lifelib/tempdir/lidka.rle.gz', tempfile='lifelib/tempdir/tempfile')
+            lidka.save('lifelib/tempdir/lidka.mc', tempfile='lifelib/tempdir/tempfile')
+            lidka.save('lifelib/tempdir/lidka.mc.gz', tempfile='lifelib/tempdir/tempfile')
 
             # Would be embarrassing if gzip didn't reduce file sizes:
             slr = os.path.getsize('lifelib/tempdir/lidka.rle')
@@ -49,10 +49,10 @@ class TestGoL(unittest.TestCase):
             self.assertLess(slrz, slr)
             self.assertLess(slmz, slm)
 
-            lr = self.lt.load('lifelib/tempdir/lidka.rle')
-            lrz = self.lt.load('lifelib/tempdir/lidka.rle.gz')
-            lm = self.lt.load('lifelib/tempdir/lidka.mc')
-            lmz = self.lt.load('lifelib/tempdir/lidka.mc.gz')
+            lr = self.lt.load('lifelib/tempdir/lidka.rle', tempfile='lifelib/tempdir/tempfile')
+            lrz = self.lt.load('lifelib/tempdir/lidka.rle.gz', tempfile='lifelib/tempdir/tempfile')
+            lm = self.lt.load('lifelib/tempdir/lidka.mc', tempfile='lifelib/tempdir/tempfile')
+            lmz = self.lt.load('lifelib/tempdir/lidka.mc.gz', tempfile='lifelib/tempdir/tempfile')
 
             # Macrocell should respect overall position; RLE need not:
             self.assertEqual(lidka, lm)
