@@ -1,7 +1,7 @@
 
 import unittest
 
-class TestCRT(unittest.TestCase):
+class TestCygwin(unittest.TestCase):
 
     def test_cygdir(self):
 
@@ -10,5 +10,10 @@ class TestCRT(unittest.TestCase):
         from lifelib import autocompile
         self.assertEqual(autocompile.cygwin_dirs, ['something'])
 
+    def test_numpy(self):
+
+        from lifelib import autocompile
+        autocompile.verify_installation()
+
 if __name__ == '__main__':
     unittest.main()
